==> s-contract-0.6.2-6.tgz: package/borsh.js <==
// Copyright 2021-2022 @skyekiwi/s-contract authors & contributors
// SPDX-License-Identifier: Apache-2.0
import { baseDecode, baseEncode, deserialize, serialize } from 'borsh';
/* eslint-disable sort-keys, camelcase */

class Call {
  constructor(config) {
    this.origin = void 0;
    this.origin_public_key = void 0;
    this.encrypted_egress = void 0;
    this.transaction_action = void 0;
    this.receiver = void 0;
    this.amount = void 0;
    this.wasm_blob = void 0;
    this.method = void 0;
    this.args = void 0;
    this.to = void 0;
    this.origin = config.origin;
    this.origin_public_key = config.origin_public_key;
    this.encrypted_egress = config.encrypted_egress;
    this.transaction_action = config.transaction_action;
    this.receiver = config.receiver;
    this.amount = config.amount;
    this.wasm_blob = config.wasm_blob;
    this.method = config.method;
    this.args = config.args;
    this.to = config.to;
  }

}

class Calls {
  constructor(config) {
    this.ops = void 0;
    this.ops = config.ops;
  }

}

class Outcome {
  constructor(config) {
    this.view_result_log = void 0;
    this.view_result = void 0;
    this.outcome_logs = void 0;
    this.outcome_receipt_ids = void 0;
    this.outcome_gas_burnt = void 0;
    this.outcome_token_burnt = void 0;
    this.outcome_executor_id = void 0;
    this.outcome_status = void 0;
    this.view_result_log = config.view_result_log;
    this.view_result = config.view_result;
    this.outcome_logs = config.outcome_logs;
    this.outcome_receipt_ids = config.outcome_receipt_ids;
    this.outcome_gas_burnt = config.outcome_gas_burnt;
    this.outcome_token_burnt = config.outcome_token_burnt;
    this.outcome_executor_id = config.outcome_executor_id;
    this.outcome_status = config.outcome_status;
  }

}

class Outcomes {
  constructor(config) {
    this.ops = void 0;
    this.state_root = void 0;
    this.ops = config.ops;
    this.state_root = config.state_root;
  }

}

class LocalMetadata {
  constructor(config) {
    this.shard_id = void 0;
    this.high_local_block = void 0;
    this.shard_id = config.shard_id;
    this.high_local_block = config.high_local_block;
  }

}

class Block {
  constructor(config) {
    this.shard_id = void 0;
    this.block_number = void 0;
    this.calls = void 0;
    this.contracts = void 0;
    this.shard_id = config.shard_id;
    this.block_number = config.block_number;
    this.calls = config.calls;
    this.contracts = config.contracts;
  }

}

class Shard {
  constructor(config) {
    this.high_remote_synced_block_index = void 0;
    this.high_remote_confirmed_block_index = void 0;
    this.high_remote_synced_block_index = config.high_remote_synced_block_index;
    this.high_remote_confirmed_block_index = config.high_remote_confirmed_block_index;
  }

}

class ShardMetadata {
  constructor(config) {
    this.shard_key = void 0;
    this.shard_members = void 0;
    this.beacon_index = void 0;
    this.threshold = void 0;
    this.shard_key = config.shard_key;
    this.shard_members = config.shard_members;
    this.beacon_index = config.beacon_index;
    this.threshold = config.threshold;
  }

}

class Contract {
  constructor(config) {
    this.home_shard = void 0;
    this.wasm_blob = void 0;
    this.deployment_call = void 0;
    this.is_initial_state_empty = void 0;
    this.home_shard = config.home_shard;
    this.wasm_blob = config.wasm_blob;
    this.deployment_call = config.deployment_call;
    this.is_initial_state_empty = config.is_initial_state_empty;
  }

}

class ExecutionSummary {
  constructor(config) {
    this.high_local_execution_block = void 0;
    this.high_local_execution_block = config.high_local_execution_block;
  }

}

const blockSchema = new Map([[Block, {
  kind: 'struct',
  fields: [['shard_id', 'u32'], ['block_number', 'u32'], ['calls', {
    kind: 'option',
    type: ['u32']
  }], ['contracts', {
    kind: 'option',
    type: ['string']
  }]]
}]]);
const callSchema = new Map([[Call, {
  kind: 'struct',
  fields: [['origin', {
    kind: 'option',
    type: 'string'
  }], ['origin_public_key', {
    kind: 'option',
    type: ['u8', 32]
  }], ['encrypted_egress', 'u8'], ['transaction_action', 'string'], ['receiver', 'string'], ['amount', {
    kind: 'option',
    type: 'u128'
  }], ['wasm_blob', {
    kind: 'option',
    type: ['u8']
  }], ['method', {
    kind: 'option',
    type: 'string'
  }], ['args', {
    kind: 'option',
    type: 'string'
  }], ['to', {
    kind: 'option',
    type: 'string'
  }]]
}]]);
const callsSchema = new Map();
callsSchema.set(Calls, {
  kind: 'struct',
  fields: [['ops', [Call]]]
});
callsSchema.set(Call, callSchema.get(Call));
const outcomeSchema = new Map([[Outcome, {
  kind: 'struct',
  fields: [['view_result_log', ['string']], ['view_result', ['u8']], ['outcome_logs', ['string']], ['outcome_receipt_ids', [['u8', 32]]], ['outcome_gas_burnt', 'u64'], ['outcome_token_burnt', 'u128'], ['outcome_executor_id', 'String'], ['outcome_status', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
const outcomesSchema = new Map();
outcomesSchema.set(Outcomes, {
  kind: 'struct',
  fields: [['ops', [Outcome]], ['state_root', ['u8', 32]]]
});
outcomesSchema.set(Outcome, outcomeSchema.get(Outcome));
const contractSchema = new Map();
contractSchema.set(Contract, {
  kind: 'struct',
  fields: [['home_shard', 'u32'], ['wasm_blob', ['u8']], ['deployment_call', Calls], ['is_initial_state_empty', 'u8']]
});
contractSchema.set(Calls, callsSchema.get(Calls));
contractSchema.set(Call, callSchema.get(Call));
const shardMetadataSchema = new Map([[ShardMetadata, {
  kind: 'struct',
  fields: [['shard_key', ['u8', 32]], ['shard_members', ['string']], ['beacon_index', 'u32'], ['threshold', 'u32']]
}]]);
const shardSchema = new Map([[Shard, {
  kind: 'struct',
  fields: [['high_remote_synced_block_index', 'u32'], ['high_remote_confirmed_block_index', 'u32']]
}]]);
const localMetadataSchema = new Map([[LocalMetadata, {
  kind: 'struct',
  fields: [['shard_id', ['u32']], ['high_local_block', 'u32']]
}]]);
const executionSummarySchema = new Map([[ExecutionSummary, {
  kind: 'struct',
  fields: [['high_local_execution_block', 'u32']]
}]]); // ser

const buildCall = call => {
  const buf = serialize(callSchema, call);
  return baseEncode(buf);
};

const buildBlock = block => {
  const buf = serialize(blockSchema, block);
  return baseEncode(buf);
};

const buildContract = contract => {
  const buf = serialize(contractSchema, contract);
  return baseEncode(buf);
};

const buildCalls = calls => {
  if (calls.ops.length === 0) {
    return '';
  }

  const buf = serialize(callsSchema, calls);
  return baseEncode(buf);
};

const buildOutcome = outcome => {
  const buf = serialize(outcomeSchema, outcome);
  return baseEncode(buf);
};

const buildOutcomes = outcomes => {
  const buf = serialize(outcomesSchema, outcomes);
  return baseEncode(buf);
};

const buildShard = shard => {
  const buf = serialize(shardSchema, shard);
  return baseEncode(buf);
};

const buildShardMetadata = shardMetadata => {
  const buf = serialize(shardMetadataSchema, shardMetadata);
  return baseEncode(buf);
};

const buildLocalMetadata = a => {
  const buf = serialize(localMetadataSchema, a);
  return baseEncode(buf);
};

const buildExecutionSummary = a => {
  const buf = serialize(executionSummarySchema, a);
  return baseEncode(buf);
}; // de


const parseCall = buf => {
  const c = deserialize(callSchema, Call, baseDecode(buf));
  c.encrypted_egress = !!c.encrypted_egress;
  return c;
};

const parseCalls = buf => {
  if (buf.length === 0) {
    return {
      ops: []
    };
  }

  const cs = deserialize(callsSchema, Calls, baseDecode(buf));

  for (let i = 0; i < cs.ops.length; i++) {
    cs.ops[i].encrypted_egress = !!cs.ops[i].encrypted_egress;
  }

  return cs;
};

const parseOutcome = buf => {
  return deserialize(outcomeSchema, Outcome, baseDecode(buf));
};

const parseOutcomes = buf => {
  return deserialize(outcomesSchema, Outcomes, baseDecode(buf));
};

const parseBlock = buf => {
  return deserialize(blockSchema, Block, baseDecode(buf));
};

const parseContract = buf => {
  const c = deserialize(contractSchema, Contract, baseDecode(buf));
  c.is_initial_state_empty = !!c.is_initial_state_empty;
  return c;
};

const parseShard = buf => {
  return deserialize(shardSchema, Shard, baseDecode(buf));
};

const parseShardMetadata = buf => {
  return deserialize(shardMetadataSchema, ShardMetadata, baseDecode(buf));
};

const parseLocalMetadata = buf => {
  return deserialize(localMetadataSchema, LocalMetadata, baseDecode(buf));
};

const parseExecutionSummary = buf => {
  return deserialize(executionSummarySchema, ExecutionSummary, baseDecode(buf));
};

export { Call, callSchema, buildCall, parseCall, Calls, callsSchema, buildCalls, parseCalls, Outcome, outcomeSchema, buildOutcome, parseOutcome, Outcomes, outcomesSchema, buildOutcomes, parseOutcomes, Block, blockSchema, buildBlock, parseBlock, Contract, contractSchema, buildContract, parseContract, Shard, shardSchema, buildShard, parseShard, ShardMetadata, shardMetadataSchema, buildShardMetadata, parseShardMetadata, LocalMetadata, localMetadataSchema, buildLocalMetadata, parseLocalMetadata, ExecutionSummary, executionSummarySchema, buildExecutionSummary, parseExecutionSummary };

==> s-contract-0.6.2-7.tgz: package/borsh.js <==
// Copyright 2021-2022 @skyekiwi/s-contract authors & contributors
// SPDX-License-Identifier: Apache-2.0
import { baseDecode, baseEncode, deserialize, serialize } from 'borsh';
/* eslint-disable sort-keys, camelcase */

class Call {
  constructor(config) {
    this.origin = void 0;
    this.origin_public_key = void 0;
    this.encrypted_egress = void 0;
    this.transaction_action = void 0;
    this.receiver = void 0;
    this.amount = void 0;
    this.wasm_blob_path = void 0;
    this.method = void 0;
    this.args = void 0;
    this.to = void 0;
    this.origin = config.origin;
    this.origin_public_key = config.origin_public_key;
    this.encrypted_egress = config.encrypted_egress;
    this.transaction_action = config.transaction_action;
    this.receiver = config.receiver;
    this.amount = config.amount;
    this.wasm_blob_path = config.wasm_blob_path;
    this.method = config.method;
    this.args = config.args;
    this.to = config.to;
  }

}

class Calls {
  constructor(config) {
    this.ops = void 0;
    this.ops = config.ops;
  }

}

class Outcome {
  constructor(config) {
    this.view_result_log = void 0;
    this.view_result = void 0;
    this.outcome_logs = void 0;
    this.outcome_receipt_ids = void 0;
    this.outcome_gas_burnt = void 0;
    this.outcome_token_burnt = void 0;
    this.outcome_executor_id = void 0;
    this.outcome_status = void 0;
    this.view_result_log = config.view_result_log;
    this.view_result = config.view_result;
    this.outcome_logs = config.outcome_logs;
    this.outcome_receipt_ids = config.outcome_receipt_ids;
    this.outcome_gas_burnt = config.outcome_gas_burnt;
    this.outcome_token_burnt = config.outcome_token_burnt;
    this.outcome_executor_id = config.outcome_executor_id;
    this.outcome_status = config.outcome_status;
  }

}

class Outcomes {
  constructor(config) {
    this.ops = void 0;
    this.state_root = void 0;
    this.ops = config.ops;
    this.state_root = config.state_root;
  }

}

class LocalMetadata {
  constructor(config) {
    this.shard_id = void 0;
    this.high_local_block = void 0;
    this.shard_id = config.shard_id;
    this.high_local_block = config.high_local_block;
  }

}

class Block {
  constructor(config) {
    this.shard_id = void 0;
    this.block_number = void 0;
    this.calls = void 0;
    this.contracts = void 0;
    this.shard_id = config.shard_id;
    this.block_number = config.block_number;
    this.calls = config.calls;
    this.contracts = config.contracts;
  }

}

class Shard {
  constructor(config) {
    this.high_remote_synced_block_index = void 0;
    this.high_remote_confirmed_block_index = void 0;
    this.high_remote_synced_block_index = config.high_remote_synced_block_index;
    this.high_remote_confirmed_block_index = config.high_remote_confirmed_block_index;
  }

}

class ShardMetadata {
  constructor(config) {
    this.shard_key = void 0;
    this.shard_members = void 0;
    this.beacon_index = void 0;
    this.threshold = void 0;
    this.shard_key = config.shard_key;
    this.shard_members = config.shard_members;
    this.beacon_index = config.beacon_index;
    this.threshold = config.threshold;
  }

}

class Contract {
  constructor(config) {
    this.wasm_blob = void 0;
    this.deployment_call = void 0;
    this.wasm_blob = config.wasm_blob;
    this.deployment_call = config.deployment_call;
  }

}

class ExecutionSummary {
  constructor(config) {
    this.high_local_execution_block = void 0;
    this.high_local_execution_block = config.high_local_execution_block;
  }

}

const blockSchema = new Map([[Block, {
  kind: 'struct',
  fields: [['shard_id', 'u32'], ['block_number', 'u32'], ['calls', {
    kind: 'option',
    type: ['u32']
  }], ['contracts', {
    kind: 'option',
    type: ['string']
  }]]
}]]);
const callSchema = new Map([[Call, {
  kind: 'struct',
  fields: [['origin', {
    kind: 'option',
    type: 'string'
  }], ['origin_public_key', {
    kind: 'option',
    type: ['u8', 32]
  }], ['encrypted_egress', 'u8'], ['transaction_action', 'string'], ['receiver', 'string'], ['amount', {
    kind: 'option',
    type: 'u128'
  }], ['wasm_blob_path', {
    kind: 'option',
    type: 'string'
  }], ['method', {
    kind: 'option',
    type: 'string'
  }], ['args', {
    kind: 'option',
    type: 'string'
  }], ['to', {
    kind: 'option',
    type: 'string'
  }]]
}]]);
const callsSchema = new Map();
callsSchema.set(Calls, {
  kind: 'struct',
  fields: [['ops', [Call]]]
});
callsSchema.set(Call, callSchema.get(Call));
const outcomeSchema = new Map([[Outcome, {
  kind: 'struct',
  fields: [['view_result_log', ['string']], ['view_result', ['u8']], ['outcome_logs', ['string']], ['outcome_receipt_ids', [['u8', 32]]], ['outcome_gas_burnt', 'u64'], ['outcome_token_burnt', 'u128'], ['outcome_executor_id', 'String'], ['outcome_status', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
const outcomesSchema = new Map();
outcomesSchema.set(Outcomes, {
  kind: 'struct',
  fields: [['ops', [Outcome]], ['state_root', ['u8', 32]]]
});
outcomesSchema.set(Outcome, outcomeSchema.get(Outcome));
const contractSchema = new Map();
contractSchema.set(Contract, {
  kind: 'struct',
  fields: [['wasm_blob', ['u8']], ['deployment_call', Calls]]
});
contractSchema.set(Calls, callsSchema.get(Calls));
contractSchema.set(Call, callSchema.get(Call));
const shardMetadataSchema = new Map([[ShardMetadata, {
  kind: 'struct',
  fields: [['shard_key', ['u8', 32]], ['shard_members', ['string']], ['beacon_index', 'u32'], ['threshold', 'u32']]
}]]);
const shardSchema = new Map([[Shard, {
  kind: 'struct',
  fields: [['high_remote_synced_block_index', 'u32'], ['high_remote_confirmed_block_index', 'u32']]
}]]);
const localMetadataSchema = new Map([[LocalMetadata, {
  kind: 'struct',
  fields: [['shard_id', ['u32']], ['high_local_block', 'u32']]
}]]);
const executionSummarySchema = new Map([[ExecutionSummary, {
  kind: 'struct',
  fields: [['high_local_execution_block', 'u32']]
}]]); // ser

const buildCall = call => {
  const buf = serialize(callSchema, call);
  return baseEncode(buf);
};

const buildBlock = block => {
  const buf = serialize(blockSchema, block);
  return baseEncode(buf);
};

const buildContract = contract => {
  const buf = serialize(contractSchema, contract);
  return baseEncode(buf);
};

const buildCalls = calls => {
  if (calls.ops.length === 0) {
    return '';
  }

  const buf = serialize(callsSchema, calls);
  return baseEncode(buf);
};

const buildOutcome = outcome => {
  const buf = serialize(outcomeSchema, outcome);
  return baseEncode(buf);
};

const buildOutcomes = outcomes => {
  const buf = serialize(outcomesSchema, outcomes);
  return baseEncode(buf);
};

const buildShard = shard => {
  const buf = serialize(shardSchema, shard);
  return baseEncode(buf);
};

const buildShardMetadata = shardMetadata => {
  const buf = serialize(shardMetadataSchema, shardMetadata);
  return baseEncode(buf);
};

const buildLocalMetadata = a => {
  const buf = serialize(localMetadataSchema, a);
  return baseEncode(buf);
};

const buildExecutionSummary = a => {
  const buf = serialize(executionSummarySchema, a);
  return baseEncode(buf);
}; // de


const parseCall = buf => {
  const c = deserialize(callSchema, Call, baseDecode(buf));
  c.encrypted_egress = !!c.encrypted_egress;
  return c;
};

const parseCalls = buf => {
  if (buf.length === 0) {
    return {
      ops: []
    };
  }

  const cs = deserialize(callsSchema, Calls, baseDecode(buf));

  for (let i = 0; i < cs.ops.length; i++) {
    cs.ops[i].encrypted_egress = !!cs.ops[i].encrypted_egress;
  }

  return cs;
};

const parseOutcome = buf => {
  return deserialize(outcomeSchema, Outcome, baseDecode(buf));
};

const parseOutcomes = buf => {
  return deserialize(outcomesSchema, Outcomes, baseDecode(buf));
};

const parseBlock = buf => {
  return deserialize(blockSchema, Block, baseDecode(buf));
};

const parseContract = buf => {
  return deserialize(contractSchema, Contract, baseDecode(buf));
};

const parseShard = buf => {
  return deserialize(shardSchema, Shard, baseDecode(buf));
};

const parseShardMetadata = buf => {
  return deserialize(shardMetadataSchema, ShardMetadata, baseDecode(buf));
};

const parseLocalMetadata = buf => {
  return deserialize(localMetadataSchema, LocalMetadata, baseDecode(buf));
};

const parseExecutionSummary = buf => {
  return deserialize(executionSummarySchema, ExecutionSummary, baseDecode(buf));
};

export { Call, callSchema, buildCall, parseCall, Calls, callsSchema, buildCalls, parseCalls, Outcome, outcomeSchema, buildOutcome, parseOutcome, Outcomes, outcomesSchema, buildOutcomes, parseOutcomes, Block, blockSchema, buildBlock, parseBlock, Contract, contractSchema, buildContract, parseContract, Shard, shardSchema, buildShard, parseShard, ShardMetadata, shardMetadataSchema, buildShardMetadata, parseShardMetadata, LocalMetadata, localMetadataSchema, buildLocalMetadata, parseLocalMetadata, ExecutionSummary, executionSummarySchema, buildExecutionSummary, parseExecutionSummary };
